@@ -25,8 +25,11 @@
 #' czso_get_catalogue()
 #' }
 czso_get_catalogue <- function() {
+  url <- "https://vdb.czso.cz/pll/eweb/lkod_ld.seznam"
 
-  suppressWarnings(readr::read_csv("https://vdb.czso.cz/pll/eweb/lkod_ld.seznam",
+  if(is_above_bigsur()) stop_on_openssl()
+
+  suppressWarnings(readr::read_csv(url,
                                    col_types = readr::cols(
                                      dataset_iri = readr::col_character(),
                                      dataset_id = readr::col_character(),
@@ -50,6 +53,7 @@ czso_get_catalogue <- function() {
 #' \lifecycle{deprecated}
 #'
 #' @return a tibble
+#' @keywords internal
 #' @examples
 #' # see `czso_get_catalogue()`
 #' @export
@@ -63,6 +67,7 @@ get_catalogue <- function() {
 #' \lifecycle{deprecated}
 #'
 #' @return a tibble
+#' @keywords internal
 #' @examples
 #' # see `czso_get_catalogue()`
 #' @export
@@ -157,7 +162,16 @@ read_czso_csv <- function(dfile) {
                                                           locale = readr::locale(encoding = guessed_enc))))
 }
 
+download_file <- function(url, dfile) {
+  if(is_above_bigsur()) stop_on_openssl()
+  curl_handle <- curl::new_handle() %>%
+    curl::handle_setheaders(.list = ua_header)
+  curl::curl_download(url, dfile, handle = curl_handle)
+  return(dfile)
+}
+
 download_if_needed <- function(url, dfile, force_redownload) {
+  if(is_above_bigsur()) stop_on_openssl()
   if(file.exists(dfile) & !force_redownload) {
     usethis::ui_info(c("File already in {usethis::ui_path(dirname(dfile))}, not downloading.",
                        "Set {usethis::ui_code('force_redownload = TRUE')} if needed."))
@@ -411,6 +425,7 @@ get_table <- function(dataset_id, resource_num = 1, force_redownload = FALSE) {
 #' czso_get_codelist("cis100vaz43")
 #' }
 #' @export
+#' @family Core workflow
 czso_get_codelist <- function(codelist_id,
                               language = c("cs", "en"),
                               dest_dir = NULL,
